!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
!                                          numgeo
!                Copyright (C) 2018-2023 Jan Machacek, Patrick Staubach
!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
!
! SUBROUTINE: user_initial_state_variables
!
!> author: Jan Machacek, jan-machacek@outlook.com
!> date: 30.03.2019
!
!> Interface to user subroutine to define the initial values for arbitrary state variables (statev)
!
!>### History
!> 30.03.2019, J. Machacek - Initial version
!> 05.07.2023, P. Staubach - Windows version
!
!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
subroutine user_initial_state_variables(ie,igp,ndim,nstatev,nchar,material,coords,statev)
  implicit none
    !DEC$ ATTRIBUTES DLLEXPORT, STDCALL, REFERENCE :: user_initial_state_variables
  integer                    , intent(in)    :: ie           !! element label
  integer                    , intent(in)    :: igp          !! integration point label
  integer                    , intent(in)    :: ndim         !! number of active dimensions
  integer                    , intent(in)    :: nstatev      !! number of stress components
  integer                    , intent(in)    :: nchar        !! length of the material name
  character                  , intent(in)    :: material(*)  !! material name
  real(8), dimension(3)      , intent(in)    :: coords       !! coordinates of the integration point
  real(8), dimension(nstatev), intent(inout) :: statev       !! initial statev
 
  real(8) :: emin, emax, Dr0, htop
  
  emin = 0.6d0
  emax = 1.0d0
  htop = 10.0d0
  
  statev(:) = 0.0d0
  
  Dr0 = 0.5 + 0.05*(htop-coords(2))

  statev(1) = emax - Dr0 * (emax - emin)
  
end subroutine user_initial_state_variables
